@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::DataInputObj;
-$AI::Pathfinding::OptimizeMultiple::DataInputObj::VERSION = '0.0.15';
+$AI::Pathfinding::OptimizeMultiple::DataInputObj::VERSION = '0.0.16';
 use strict;
 use warnings;
 
@@ -9,15 +9,18 @@ use MooX qw/late/;
 
 use File::Path qw(mkpath);
 
-use AI::Pathfinding::OptimizeMultiple::Scan;
+use AI::Pathfinding::OptimizeMultiple::Scan ();
 
-use PDL (qw( pdl ));
+use PDL              (qw( pdl ));
 use PDL::IO::FastRaw (qw( readfraw writefraw ));
 
-has start_board => (isa => 'Int', is => 'ro', required => 1);
-has num_boards => (isa => 'Int', is => 'ro', required => 1);
-has selected_scans => (isa => 'ArrayRef', is => 'ro', required => 1,
-    default => sub {
+has start_board    => ( isa => 'Int', is => 'ro', required => 1 );
+has num_boards     => ( isa => 'Int', is => 'ro', required => 1 );
+has selected_scans => (
+    isa      => 'ArrayRef',
+    is       => 'ro',
+    required => 1,
+    default  => sub {
         my ($self) = @_;
 
         return $self->_calc_selected_scan_list();
@@ -25,13 +28,15 @@ has selected_scans => (isa => 'ArrayRef', is => 'ro', required => 1,
     lazy => 1,
 );
 
-has _scan_ids_to_indexes => (isa => 'HashRef[Int]', is => 'ro',
-    lazy => 1,
+has _scan_ids_to_indexes => (
+    isa     => 'HashRef[Int]',
+    is      => 'ro',
+    lazy    => 1,
     default => sub {
         my ($self) = @_;
 
         my $scan_ids = $self->get_scan_ids_aref;
-        return +{ map { $scan_ids->[$_] => $_} 0 .. $#$scan_ids };
+        return +{ map { $scan_ids->[$_] => $_ } 0 .. $#$scan_ids };
     },
 );
 
@@ -57,7 +62,7 @@ sub _read_text_ints_file
 
     my $text = _slurp($filename);
 
-    return [split(/[\n\r]+/, $text)];
+    return [ split( /[\n\r]+/, $text ) ];
 }
 
 # Number of selected scans.
@@ -65,32 +70,32 @@ sub _num_sel_scans
 {
     my $self = shift;
 
-    return scalar(@{$self->selected_scans()});
+    return scalar( @{ $self->selected_scans() } );
 }
 
 sub _gen_initial_scans_tensor
 {
-    my $self = shift;
+    my $self       = shift;
     my $extra_dims = shift || [];
 
-    return zeroes($self->num_boards(), $self->_num_sel_scans, @$extra_dims);
+    return zeroes( $self->num_boards(), $self->_num_sel_scans, @$extra_dims );
 }
 
 sub _should_update
 {
-    my ($self, $src_path, $dest_path) = @_;
+    my ( $self, $src_path, $dest_path ) = @_;
 
     my @orig_stat = stat($src_path);
     my @proc_stat = stat($dest_path);
 
-    return ((! @proc_stat) || ($orig_stat[9] > $proc_stat[9]));
+    return ( ( !@proc_stat ) || ( $orig_stat[9] > $proc_stat[9] ) );
 }
 
 # Number of numbers in the header of the solutions' iteration counts
 my $NUM_NUMBERS_IN_HEADER = 3;
 
-my $HEADER_START_BOARD_IDX = 0;
-my $HEADER_NUM_BOARDS = 1;
+my $HEADER_START_BOARD_IDX  = 0;
+my $HEADER_NUM_BOARDS       = 1;
 my $HEADER_ITERATIONS_LIMIT = 2;
 
 sub _get_scans_data_helper
@@ -101,55 +106,57 @@ sub _get_scans_data_helper
 
     my $start_board = $self->start_board();
 
-    my $scans_data = {};
+    my $scans_data      = {};
     my $scans_lens_data = {};
 
-    my $scan_idx = 0;
-
     my $data_dir = ".data-proc";
     my $lens_dir = ".data-len-proc";
 
-    mkpath([$data_dir, $lens_dir]);
+    mkpath( [ $data_dir, $lens_dir ] );
 
     foreach my $scan (@$selected_scans)
     {
         {
             my $dest_path = $data_dir . "/" . $scan->id();
             {
-                if ($self->_should_update($scan->data_file_path(), $dest_path))
-                {
-                    my $data_s = _slurp($scan->data_file_path());
-                    my @array = unpack("l*", $data_s);
-                    if (($array[$HEADER_START_BOARD_IDX] != 1) ||
-                        ($array[$HEADER_NUM_BOARDS] < $self->num_boards)
+                if (
+                    $self->_should_update(
+                        $scan->data_file_path(), $dest_path
                     )
+                    )
+                {
+                    my $data_s = _slurp( $scan->data_file_path() );
+                    my @array  = unpack( "l*", $data_s );
+                    if (   ( $array[$HEADER_START_BOARD_IDX] != 1 )
+                        || ( $array[$HEADER_NUM_BOARDS] < $self->num_boards ) )
                     {
-                        die "Incorrect file format in scan " . $scan->{'id'} . "!\n";
+                        die "Incorrect file format in scan "
+                            . $scan->{'id'} . "!\n";
                     }
 
-                    my $c = pdl(\@array);
+                    my $c = pdl( \@array );
 
-                    writefraw($c, $dest_path);
+                    writefraw( $c, $dest_path );
                 }
             }
             {
-                my $start_idx = $NUM_NUMBERS_IN_HEADER + ($start_board - 1);
-                my $scan_vec = readfraw($dest_path);
-                $scans_data->{$scan->id()} = $scan_vec->slice(
-                    $start_idx.":".($start_idx + $self->num_boards()-1)
-                );
+                my $start_idx = $NUM_NUMBERS_IN_HEADER + ( $start_board - 1 );
+                my $scan_vec  = readfraw($dest_path);
+                $scans_data->{ $scan->id() } =
+                    $scan_vec->slice( $start_idx . ":"
+                        . ( $start_idx + $self->num_boards() - 1 ) );
             }
         }
         {
-            my $src = $scan->data_file_path();
+            my $src  = $scan->data_file_path();
             my $dest = "$lens_dir/" . $scan->id();
 
-            if ($self->_should_update($src, $dest))
+            if ( $self->_should_update( $src, $dest ) )
             {
                 my $data_s = _slurp($src);
 
-                my @iters = unpack("l*", $data_s);
-                if ( ($iters[0] != 1) || ($iters[1] < $self->num_boards()) )
+                my @iters = unpack( "l*", $data_s );
+                if ( ( $iters[0] != 1 ) || ( $iters[1] < $self->num_boards() ) )
                 {
                     die "Incorrect file format in scan " . $scan->id() . "!\n";
                 }
@@ -158,41 +165,36 @@ sub _get_scans_data_helper
                 splice @iters, 0, $NUM_NUMBERS_IN_HEADER;
 
                 my $c = pdl(
-                    [\@iters,
-                    $self->_read_text_ints_file(
-                        "data/" . $scan->id() . ".fcs.moves.txt"
-                    ),
-                    $self->_read_text_ints_file(
-                        "data/" . $scan->id() . ".fcpro.moves.txt"
-                    ),
+                    [
+                        \@iters,
+                        $self->_read_text_ints_file(
+                            "data/" . $scan->id() . ".fcs.moves.txt"
+                        ),
+                        $self->_read_text_ints_file(
+                            "data/" . $scan->id() . ".fcpro.moves.txt"
+                        ),
                     ]
                 );
 
-                writefraw($c, $dest);
+                writefraw( $c, $dest );
             }
             {
                 my $scan_vec = readfraw($dest);
-                $scans_lens_data->{$scan->id()} = $scan_vec->slice(
-                    sprintf(
-                        "%d:%d,:,*",
-                        ($start_board-1),
-                        (($self->num_boards()-1)+($start_board-1))
-                    )
-                )->xchg(1,2);
+                $scans_lens_data->{ $scan->id() } = $scan_vec->slice(
+                    sprintf( "%d:%d,:,*",
+                        ( $start_board - 1 ),
+                        ( ( $self->num_boards() - 1 ) + ( $start_board - 1 ) ) )
+                )->xchg( 1, 2 );
             }
         }
     }
-    continue
-    {
-        $scan_idx++;
-    }
 
     return { 'scans' => $scans_data, 'with_lens' => $scans_lens_data };
 }
 
 sub _get_scans_data_generic
 {
-    my ($self, $id) = @_;
+    my ( $self, $id ) = @_;
 
     return $self->_get_scans_data_helper()->{$id};
 }
@@ -213,29 +215,22 @@ sub get_scans_lens_iters_pdls
 
 sub _filter_scans_based_on_black_list_ids
 {
-    my ($scans, $black_list_ids) = @_;
+    my ( $scans, $black_list_ids ) = @_;
 
-    my %black_list = (map { /(\d+)/?($1 => 1) : () } @$black_list_ids);
+    my %black_list = ( map { /(\d+)/ ? ( $1 => 1 ) : () } @$black_list_ids );
 
-    return
-        [grep
-            {
-                !exists($black_list{$_->id()})
-            }
-            @$scans
-        ];
+    return [ grep { !exists( $black_list{ $_->id() } ) } @$scans ];
 }
 
 sub _is_scan_suitable
 {
-    my ($self, $scan) = @_;
+    my ( $self, $scan ) = @_;
 
-    my @stat = stat($scan->data_file_path());
-    return
-    (
+    my @stat = stat( $scan->data_file_path() );
+    return (
         scalar(@stat)
-            &&
-        ($stat[7] >= 12 + ($self->num_boards() + $self->start_board() -1) * 4)
+            && ( $stat[7] >=
+            12 + ( $self->num_boards() + $self->start_board() - 1 ) * 4 )
     );
 }
 
@@ -254,14 +249,14 @@ sub _get_all_scans_list_from_file
 
     open my $scans_fh, "<", $scans_fn
         or die "Could not open '$scans_fn' - $!.";
-    while (my $line = <$scans_fh>)
+    while ( my $line = <$scans_fh> )
     {
         chomp($line);
-        my ($id, $cmd_line) = split(/\t/, $line);
+        my ( $id, $cmd_line ) = split( /\t/, $line );
         push @scans,
             AI::Pathfinding::OptimizeMultiple::Scan->new(
-                id => $id,
-                cmd_line => $cmd_line
+            id       => $id,
+            cmd_line => $cmd_line
             );
     }
     close($scans_fh);
@@ -286,25 +281,18 @@ sub _suitable_scans_list
 {
     my $self = shift;
 
-    return
-    [
-        grep
-        {
-            $self->_is_scan_suitable($_)
-        }
-        @{$self->_get_all_scans_list_from_file()}
-    ];
+    return [ grep { $self->_is_scan_suitable($_) }
+            @{ $self->_get_all_scans_list_from_file() } ];
 }
 
 sub _calc_selected_scan_list
 {
     my $self = shift;
 
-    return
-        _filter_scans_based_on_black_list_ids(
-            $self->_suitable_scans_list(),
-            $self->_black_list_ids_list(),
-        )
+    return _filter_scans_based_on_black_list_ids(
+        $self->_suitable_scans_list(),
+        $self->_black_list_ids_list(),
+    );
 }
 
 sub _get_next_id_file_path
@@ -328,7 +316,7 @@ sub get_next_id
     close($in);
 
     open my $out, ">", $fn;
-    print {$out} ($id+1);
+    print {$out} ( $id + 1 );
     close($out);
 
     return $id;
@@ -343,11 +331,11 @@ sub get_prev_scans
     my $scans_fn = $self->_get_scans_registry_file_path;
 
     open my $in, "<", $scans_fn
-        or die "Could not open '$scans_fn' - $!.";;
-    while (my $line = <$in>)
+        or die "Could not open '$scans_fn' - $!.";
+    while ( my $line = <$in> )
     {
         chomp($line);
-        my ($scan_id, $cmd_line) = split(/\t/, $line);
+        my ( $scan_id, $cmd_line ) = split( /\t/, $line );
         push @prev_scans, { 'id' => $scan_id, 'cmd_line' => $cmd_line };
     }
     close($in);
@@ -362,26 +350,27 @@ sub _get_scan_cmd_line
 
     my $min_board = $args->{'min'} || 1;
     my $max_board = $args->{'max'} || 32_000;
-    my $id = $args->{'id'};
-    my $argv = $args->{'argv'};
-    my @fc_num =
-        (exists($args->{'freecells_num'})
-            ?  ("--freecells-num" , $args->{'freecells_num'})
-            : ()
-        );
-    my @variant =
-        (exists($args->{'variant'})
-            ? ("--variant", $args->{'variant'})
-            : ()
-        );
+    my $id        = $args->{'id'};
+    my $argv      = $args->{'argv'};
+    my @fc_num    = (
+        exists( $args->{'freecells_num'} )
+        ? ( "--freecells-num", $args->{'freecells_num'} )
+        : ()
+    );
+    my @variant = (
+        exists( $args->{'variant'} )
+        ? ( "--variant", $args->{'variant'} )
+        : ()
+    );
 
-    return
-    [
+    return [
         qw(freecell-solver-fc-pro-range-solve),
-        $min_board, $max_board, "20",
+        $min_board,
+        $max_board,
+        "20",
         @variant,
         '--total-iterations-limit',
-        ($ENV{FC_SOLVE_RANGE_ITERS_LIMIT} // 100000),
+        ( $ENV{FC_SOLVE_RANGE_ITERS_LIMIT} // 100000 ),
         '--binary-output-to',
         "data/$id.data.bin",
         @$argv,
@@ -396,25 +385,25 @@ sub time_scan
 
     my $min_board = $args->{'min'} || 1;
     my $max_board = $args->{'max'} || 32_000;
-    my $id = $args->{'id'};
+    my $id        = $args->{'id'};
 
     my $cmd_line = $self->_get_scan_cmd_line($args);
 
     open my $from_cmd, "-|", @$cmd_line
         or die "Could not start '@$cmd_line'";
-    open my $fcs_out, ">", "data/$id.fcs.moves.txt";
+    open my $fcs_out,    ">", "data/$id.fcs.moves.txt";
     open my $fc_pro_out, ">", "data/$id.fcpro.moves.txt";
     $fcs_out->autoflush(1);
     $fc_pro_out->autoflush(1);
-    while (my $line = <$from_cmd>)
+    while ( my $line = <$from_cmd> )
     {
         print $line;
         chomp($line);
-        if ($line =~ m{\A\[\[Num FCS Moves\]\]=(.*)\z}o)
+        if ( $line =~ m{\A\[\[Num FCS Moves\]\]=(.*)\z}o )
         {
             print {$fcs_out} "$1\n";
         }
-        elsif ($line =~ m{\A\[\[Num FCPro Moves\]\]=(.*)\z}o)
+        elsif ( $line =~ m{\A\[\[Num FCPro Moves\]\]=(.*)\z}o )
         {
             print {$fc_pro_out} "$1\n";
         }
@@ -428,15 +417,15 @@ sub get_scan_ids_aref
 {
     my $self = shift;
 
-    return [map { $_->id() } @{ $self->selected_scans }];
+    return [ map { $_->id() } @{ $self->selected_scans } ];
 }
 
 sub lookup_scan_idx_based_on_id
 {
-    my ($self, $scan_id) = @_;
+    my ( $self, $scan_id ) = @_;
 
     my $idx = $self->_scan_ids_to_indexes->{$scan_id};
-    if (!defined($idx))
+    if ( !defined($idx) )
     {
         die "Index '$idx' does not exist!";
     }
@@ -458,11 +447,7 @@ AI::Pathfinding::OptimizeMultiple::DataInputObj - handle the data input.
 
 =head1 VERSION
 
-version 0.0.15
-
-=head1 VERSION
-
-version 0.0.15
+version 0.0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -507,37 +492,10 @@ Get an array reference of the scan IDs.
 $scan_id is a string and lookup_scan_idx_based_on_id() looks up its index
 in the scans.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2012 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc AI::Pathfinding::OptimizeMultiple
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -551,15 +509,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/AI-Pathfinding-OptimizeMultiple>
+L<https://metacpan.org/release/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -571,30 +521,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMulti
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -605,7 +531,7 @@ L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/A/AI-Pathfinding-OptimizeMultiple>
 
@@ -643,4 +569,25 @@ L<http://github.com/shlomif/fc-solve>
 
   git clone ssh://git@github.com/shlomif/fc-solve.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
