@@ -1,5 +1,5 @@
 package AI::Pathfinding::OptimizeMultiple::SimulationResults;
-$AI::Pathfinding::OptimizeMultiple::SimulationResults::VERSION = '0.0.15';
+$AI::Pathfinding::OptimizeMultiple::SimulationResults::VERSION = '0.0.16';
 use strict;
 use warnings;
 
@@ -7,9 +7,13 @@ use 5.012;
 
 use MooX qw/late/;
 
-has status => (isa => 'Str', is => 'ro', required => 1,);
-has total_iters => (isa => 'Int', is => 'ro', required => 1,);
-has scan_runs => (isa => 'ArrayRef[AI::Pathfinding::OptimizeMultiple::ScanRun]', is => 'ro', required => 1,);
+has status      => ( isa => 'Str', is => 'ro', required => 1, );
+has total_iters => ( isa => 'Int', is => 'ro', required => 1, );
+has scan_runs   => (
+    isa      => 'ArrayRef[AI::Pathfinding::OptimizeMultiple::ScanRun]',
+    is       => 'ro',
+    required => 1,
+);
 
 sub get_total_iters
 {
@@ -35,7 +39,7 @@ AI::Pathfinding::OptimizeMultiple::SimulationResults - the simulation results.
 
 =head1 VERSION
 
-version 0.0.15
+version 0.0.16
 
 =head1 SYNOPSIS
 
@@ -43,10 +47,6 @@ version 0.0.15
 
 A class for simulation results.
 
-=head1 VERSION
-
-version 0.0.15
-
 =head1 SUBROUTINES/METHODS
 
 =head2 $scan_run->status()
@@ -77,37 +77,10 @@ L<AI::Pathfinding::OptimizeMultiple> , L<AI::Pathfinding::OptimizeMultiple::Scan
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2012 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc AI::Pathfinding::OptimizeMultiple
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -121,15 +94,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/AI-Pathfinding-OptimizeMultiple>
+L<https://metacpan.org/release/AI-Pathfinding-OptimizeMultiple>
 
 =item *
 
@@ -141,30 +106,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=AI-Pathfinding-OptimizeMulti
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/AI-Pathfinding-OptimizeMultiple>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -175,7 +116,7 @@ L<http://cpants.cpanauthors.org/dist/AI-Pathfinding-OptimizeMultiple>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/A/AI-Pathfinding-OptimizeMultiple>
 
@@ -213,4 +154,25 @@ L<http://github.com/shlomif/fc-solve>
 
   git clone ssh://git@github.com/shlomif/fc-solve.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/ai-pathfinding-optimizemultiple/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
